@@ -54,13 +54,26 @@ def _update_params(hyperopt_params, params):
     return hyperopt_params
 
 
-def opt_catboost(X_train, y_train, cat_features=None, cv_folds=3, n_trials=20, verbose=0, params=None, device='GPU', max_rounds=5000, seed=0, early_stopping=20, figsize=(15,6)):
+def opt_catboost(X_train,
+                 y_train,
+                 cat_features=None,
+                 cv_folds=3,
+                 folds=None,
+                 n_trials=20,
+                 verbose=0,
+                 params=None,
+                 device='GPU',
+                 max_rounds=5000,
+                 seed=0,
+                 early_stopping=20,
+                 figsize=(15,6)):
     """
     Performs n_trials using Hyperopt to obtain the best catboost parameters
 
     Inputs:
         X_train, y_train, cat_features: Data to build Pool object
         cv_folds: number of CV folds for validation on each trial
+        folds: Custom splitting indices. This parameter has the highest priority among other data split parameters.
         n_trials: number of trials to perform
         verbose: 0 = no log and no plot, 1 = log but no plot, 2 = log and plot
         params: dict to override the Hyperopt params
@@ -112,6 +125,7 @@ def opt_catboost(X_train, y_train, cat_features=None, cv_folds=3, n_trials=20, v
                    verbose=False,
                    seed=seed,
                    early_stopping_rounds=early_stopping,
+                   folds=folds
                    as_pandas=True)
 
         # Metric to extract the loss from
