@@ -6,8 +6,8 @@ from efficientnet_pytorch import EfficientNet
 from torch import nn
 import geffnet.gen_efficientnet as efn
 
-EFNS = [efn.efficientnet_b0, efn.efficientnet_b1, efn.efficientnet_b2, efn.efficientnet_b3,
-        efn.efficientnet_b4, efn.efficientnet_b5, efn.efficientnet_b6, efn.efficientnet_b7]
+EFNS = [efn.tf_efficientnet_b0, efn.tf_efficientnet_b1, efn.tf_efficientnet_b2, efn.tf_efficientnet_b3,
+        efn.tf_efficientnet_b4, efn.tf_efficientnet_b5, efn.tf_efficientnet_b6, efn.tf_efficientnet_b7]
 
 class Identity(nn.Module):
         def __init__(self):
